==> haskell-config-ini-0.2.6.0-35-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-config-ini.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 config-ini
version:              0.2.6.0
visibility:           public
id:                   config-ini-0.2.6.0-KTD6c77d88MEmxH3bxPq0O
key:                  config-ini-0.2.6.0-KTD6c77d88MEmxH3bxPq0O
license:              BSD-3-Clause
copyright:            ©2018 Getty Ritter
maintainer:           Getty Ritter <config-ini@infinitenegativeutility.com>
author:               Getty Ritter <config-ini@infinitenegativeutility.com>
homepage:             https://github.com/aisamanra/config-ini
synopsis:             A library for simple INI-based configuration files.
description:
    The @config-ini@ library is a set of small monadic languages
    for writing simple configuration languages with convenient,
    human-readable error messages.

    > parseConfig :: IniParser (Text, Int, Bool)
    > parseConfig = section "NETWORK" $ do
    >   user <- field        "user"
    >   port <- fieldOf      "port" number
    >   enc  <- fieldFlagDef "encryption" True
    >   return (user, port, enc)

category:             Configuration
abi:                  78224ed14d9b6380b0173f7f19bc631c
exposed:              True
exposed-modules:
    Data.Ini.Config Data.Ini.Config.Bidir Data.Ini.Config.Raw

import-dirs:          /usr/lib/ghc-9.2.8/site-local/config-ini-0.2.6.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/config-ini-0.2.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-config-ini
hs-libraries:         HSconfig-ini-0.2.6.0-KTD6c77d88MEmxH3bxPq0O
depends:
    base-4.16.4.0 containers-0.6.5.1
    megaparsec-9.5.0-Jwu5LIKr9Z8JTb6Qjv9hi0 text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.20-6SQIi6GiFzoJl2Kyo4GEMQ

haddock-interfaces:   /usr/share/doc/haskell-config-ini/html/config-ini.haddock
haddock-html:         /usr/share/doc/haskell-config-ini/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-config-ini-0.2.6.0-41-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-config-ini.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 config-ini
version:              0.2.6.0
visibility:           public
id:                   config-ini-0.2.6.0-dE8mKuQvv01cMh1BKoQQf
key:                  config-ini-0.2.6.0-dE8mKuQvv01cMh1BKoQQf
license:              BSD-3-Clause
copyright:            ©2018 Getty Ritter
maintainer:           Getty Ritter <config-ini@infinitenegativeutility.com>
author:               Getty Ritter <config-ini@infinitenegativeutility.com>
homepage:             https://github.com/aisamanra/config-ini
synopsis:             A library for simple INI-based configuration files.
description:
    The @config-ini@ library is a set of small monadic languages
    for writing simple configuration languages with convenient,
    human-readable error messages.

    > parseConfig :: IniParser (Text, Int, Bool)
    > parseConfig = section "NETWORK" $ do
    >   user <- field        "user"
    >   port <- fieldOf      "port" number
    >   enc  <- fieldFlagDef "encryption" True
    >   return (user, port, enc)

category:             Configuration
abi:                  05ef5786190ae76018e0023f9758f6e0
exposed:              True
exposed-modules:
    Data.Ini.Config Data.Ini.Config.Bidir Data.Ini.Config.Raw

import-dirs:          /usr/lib/ghc-9.2.8/site-local/config-ini-0.2.6.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/config-ini-0.2.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-config-ini
hs-libraries:         HSconfig-ini-0.2.6.0-dE8mKuQvv01cMh1BKoQQf
depends:
    base-4.16.4.0 containers-0.6.5.1
    megaparsec-9.6.0-6jYDQ0q8YWM1z9BbCkR7uD text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu

haddock-interfaces:   /usr/share/doc/haskell-config-ini/html/config-ini.haddock
haddock-html:         /usr/share/doc/haskell-config-ini/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
